Tutorial
========


Creating a new card game
------------------------

Creating your cards
^^^^^^^^^^^^^^^^^^^


Inheriting from the Abstract Class
""""""""""""""""""""""""""""""""""


First you need to define some fields for your card.
You can do that by inheriting from
